@@ -25,10 +25,10 @@ class ConfigParameter(param.Parameter):
         super()._set_names(attrib_name)
         
 class Config(param.Parameterized):
-    API_SERVER = ConfigParameter(str, env_prefix="xestore", default="https://xestore-dot-xenon-pmts.uc.r.appspot.com/v1")
-    AUTH_SERVER_URI = ConfigParameter(str, env_prefix="xestore", default="https://pmts.xenonnt.org/db_api/jwt/device/")
-    API_TOKEN = ConfigParameter(str, env_prefix="xestore", default="")
-    DEBUG = ConfigParameter(bool, env_prefix="xestore", default=False)
+    API_SERVER = ConfigParameter(str, env_prefix="xepmts", default="https://xestore-dot-xenon-pmts.uc.r.appspot.com/v1")
+    AUTH_SERVER_URI = ConfigParameter(str, env_prefix="xepmts", default="https://pmts.xenonnt.org/db_api/jwt/device/")
+    API_TOKEN = ConfigParameter(str, env_prefix="xepmts", default="")
+    DEBUG = ConfigParameter(bool, env_prefix="xepmts", default=False)
     MAX_LOG_SIZE = 20
     MAX_MESSAGES = 3
     META_FIELDS = ["_version", "_latest_version", "_etag", "_created"]
