@@ -19,7 +19,7 @@ from panel.io.server import unlocked
 from tornado.ioloop import IOLoop
 
 
-executor = ThreadPoolExecutor(max_workers=5)
+executor = ThreadPoolExecutor(max_workers=20)
 logger = logging.getLogger(__name__)
 
 
@@ -69,6 +69,7 @@ class DAQStreamz(param.Parameterized):
             
         except Exception as e:
             print(e)
+            print(r.content)
             result = {
                 "rates": self.rates_example[["time", "signal_channel", "rate"]].to_dict(orient="list"),
                 "reader_info": self.reader_info_example.to_dict(orient="list"),
@@ -182,13 +183,21 @@ class DAQStreamz(param.Parameterized):
                         y=self.yaxis,
                         c="rate",
                         s=180,
-                        by=self.groupby,
-                        subplots=True,
                         cmap=self.colormap,
                         responsive=True,
                         backlog=nitems)
         psettings.update(kwargs)
-        return sdf.hvplot.scatter(**psettings)
+        if self.rates_base_info is None:
+            return sdf.hvplot.scatter(**psettings)
+        groups = self.rates_base_info[self.groupby].unique()
+        plot = None
+        for group in groups:
+            p = sdf[sdf[self.groupby]==group].hvplot.scatter(**psettings)
+            if plot is None:
+                plot = p
+            else:
+                plot = plot + p
+        return plot
 
         groups = self.rates_base_info[self.groupby].unique()
         if len(groups)>1:
@@ -343,7 +352,7 @@ class LiveDAQStreamz(DAQStreamz):
 class LiveDAQStreamzViewer(param.Parameterized):
     
     CONFIGS = {
-        "tpc": dict(xaxis="position_x", yaxis="position_y", groupby="array", reader_names=[f"reader{i}_reader_0" for i in range(4)]),
+        "tpc": dict(xaxis="position_x", yaxis="position_y", groupby="array", reader_names=[f"reader{i}_reader_0" for i in range(3)]),
         "nveto": dict(xaxis="sector", yaxis="array", groupby="detector", reader_names=["reader6_reader_0", "reader6_reader_1"]),
         "muveto": dict(xaxis="sector", yaxis="array", groupby="detector", reader_names=["reader5_reader_0"]),
 
@@ -403,7 +412,6 @@ class LiveDAQStreamzViewer(param.Parameterized):
                       self.param.reload_detector,
                      sizing_mode="stretch_width")
     
-    
     def view(self):
         return pn.Column(
             self.controls(),
